@@ -500,7 +500,7 @@ class Fitter(object):
                                                                 self.weighting_model)
                 self._process_fitting_results(key + '_' + str(i))
         if self.write_output is True and hasattr(self, "fit_data"):
-            outfile = open('outfile.yaml', 'W')
+            outfile = open('outfile.yaml', 'w')
             yaml.dump(self.fit_data, outfile)
         elif not hasattr(self, "fit_data"):
             logger.info("There was no file to process")
@@ -1360,11 +1360,10 @@ class Fitter(object):
         titlebegin = "Lin-KK test "
 
         if save != self.savefig:
-            logger.warning("Used the global `savefig` attribute instead of the `save` kwarg.")
+            logger.warning("Kwarg `savefig' is overwriting the global `savefig` attribute.")
             save = self.savefig
         if show != self.show:
-            logger.warning("Used the global `show` attribute instead of the `show` kwarg.")
-            show = self.show
+            logger.warning("Kwarg `show' is overwriting the global `show` attribute.")
 
         if capacitance:
             titlebegin += "capacitance "
